@@ -9,7 +9,6 @@ from qiniu import config
 import qiniu.auth
 from . import __version__
 
-
 _sys_info = '{0}; {1}'.format(platform.system(), platform.machine())
 _python_ver = platform.python_version()
 
@@ -73,14 +72,20 @@ def _put(url, data, files, auth, headers=None):
     return __return_wrapper(r)
 
 
-def _get(url, params, auth):
+def _get(url, params, auth, headers=None):
+    if _session is None:
+        _init()
     try:
-        r = requests.get(
+        post_headers = _headers.copy()
+        if headers is not None:
+            for k, v in headers.items():
+                post_headers.update({k: v})
+        r = _session.get(
             url,
             params=params,
-            auth=qiniu.auth.RequestsAuth(auth) if auth is not None else None,
+            auth=auth,
             timeout=config.get_default('connection_timeout'),
-            headers=_headers)
+            headers=post_headers)
     except Exception as e:
         return None, ResponseInfo(None, e)
     return __return_wrapper(r)
@@ -107,10 +112,18 @@ def _post_with_auth(url, data, auth):
     return _post(url, data, None, qiniu.auth.RequestsAuth(auth))
 
 
+def _get_with_auth(url, data, auth):
+    return _get(url, data,  qiniu.auth.RequestsAuth(auth))
+
+
 def _post_with_auth_and_headers(url, data, auth, headers):
     return _post(url, data, None, qiniu.auth.RequestsAuth(auth), headers)
 
 
+def _get_with_auth_and_headers(url, data, auth, headers):
+    return _get(url, data, qiniu.auth.RequestsAuth(auth), headers)
+
+
 def _post_with_qiniu_mac_and_headers(url, data, auth, headers):
     return _post(url, data, None, qiniu.auth.QiniuMacRequestsAuth(auth), headers)
 
@@ -232,11 +245,14 @@ class ResponseInfo(object):
             self.req_id = response.headers.get('X-Reqid')
             self.x_log = response.headers.get('X-Log')
             if self.status_code >= 400:
-                ret = response.json() if response.text != '' else None
-                if ret is None or ret['error'] is None:
-                    self.error = 'unknown'
+                if 600 > self.status_code >= 499:
+                    self.error = response.text
                 else:
-                    self.error = ret['error']
+                    ret = response.json() if response.text != '' else None
+                    if ret is None or ret['error'] is None:
+                        self.error = 'unknown'
+                    else:
+                        self.error = ret['error']
             if self.req_id is None and self.status_code == 200:
                 self.error = 'server is not qiniu'
 
